@@ -145,12 +145,22 @@ update_pango_layout (GnomeIconTextItem *iti)
 		text = iti->text;
 	}
 
+	pango_layout_set_wrap (priv->layout, PANGO_WRAP_WORD);
 	pango_layout_set_text (priv->layout, text, strlen (text));
-
 	pango_layout_set_width (priv->layout, iti->width * PANGO_SCALE);
 
+	/* In PANGO_WRAP_WORD mode, words wider than a line of text make
+	 * PangoLayout overflow the layout width.  If this happens, switch to
+	 * character-based wrapping.
+	 */
+
 	pango_layout_get_pixel_extents (iti->_priv->layout, NULL, &bounds);
 
+	if (bounds.width > iti->width) {
+		pango_layout_set_wrap (priv->layout, PANGO_WRAP_CHAR);
+		pango_layout_get_pixel_extents (iti->_priv->layout, NULL, &bounds);
+	}
+
 	priv->layout_width = bounds.width;
 	priv->layout_height = bounds.height;
 }
@@ -581,14 +591,16 @@ gnome_icon_text_item_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 				    xofs + 1, yofs + 1,
 				    w - 2, h - 2);
 
-	if (iti->focused && ! iti->editing) {
+	if (GTK_WIDGET_HAS_FOCUS (widget) && iti->focused && ! iti->editing) {
 		GdkRectangle r;
 
 		r.x = xofs;
 		r.y = yofs;
 		r.width = w - 1;
 		r.height = h - 1;
-		gtk_paint_focus (style, drawable, state, &r, widget, NULL,
+		gtk_paint_focus (style, drawable,
+				 iti->selected ? GTK_STATE_SELECTED: GTK_STATE_NORMAL,
+				 &r, widget, NULL,
 				 xofs, yofs, w - 1, h - 1);
 #if 0
 		gtk_draw_focus (style,
